@@ -1,16 +1,20 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use warnings;
-use strict;
+# This code is part of distribution Log-Report. Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Log::Report::Dispatcher::Syslog;
 use vars '$VERSION';
-$VERSION = '1.18';
+$VERSION = '1.27';
 
 use base 'Log::Report::Dispatcher';
 
+use warnings;
+use strict;
+
 use Log::Report 'log-report';
 
 use Sys::Syslog        qw/:standard :extended :macros/;
@@ -104,7 +108,7 @@ sub log($$$$$)
 
     # handle each line in message separately
     $text    =~ s/\s+$//s;
-    my @text = split /\n/, $format->($text, $domain, $msg);
+    my @text = split /\n/, $format->($text, $domain, $msg, %$opts);
 
     my $prio    = $self->reasonToPrio($reason);
     my $charset = $self->{LRDS_charset};
